SystemOrganization addCategory: #'Hipay-Tests'!

TestCase subclass: #HPEnvironmentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Tests'!

!HPEnvironmentTest methodsFor: 'testing' stamp: 'FrancoisStephany 1/29/2012 15:05'!
testformElementsFor
	| env formElementDictionary |
	env := HPEnvironment new 
		beTest;
		websiteId: '12345';
		userAccountId: '9090';
		categoryId: '545';
		key: 'abcde'.
 	formElementDictionary := env formElementsFor: HPOrder new.
	self assert: (formElementDictionary includesKey: #websiteId).
	self assert: (formElementDictionary includesKey: #mode).
	self assert: (formElementDictionary includesKey: #data).
	self assert: (formElementDictionary includesKey: #sign).
	self assert: (formElementDictionary includesKey: #url).! !

TestCase subclass: #HPOrderItemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Tests'!

!HPOrderItemTest methodsFor: 'testing' stamp: 'FrancoisStephany 1/29/2012 16:40'!
testGenerateXMLElementWithId
	| item node |
	item := HPOrderItem new
		amount: 42.5;
		categoryId: 545;
		name: 'The Seaside book.';
		infos: 'The best Seaside resource';
		reference: 'ZZ45B';
		quantity: 17.
	node := item generateXMLElementWithId: 1.
	self assert: node name equals: 'item'.
	self assert: (node attributeAt: 'id') equals: '1'.
	self assert: (node findElementNamed: 'amount') contentString equals: '42.5'.
	self assert: (node findElementNamed: 'categoryId') contentString equals: '545'.
	self assert: (node findElementNamed: 'name') contentString equals: 'The Seaside book.'.
	self assert: (node findElementNamed: 'infos') contentString equals: 'The best Seaside resource'.
	self assert: (node findElementNamed: 'reference') contentString equals: 'ZZ45B'.
	self assert: (node findElementNamed: 'quantity') contentString equals: '17'.! !

TestCase subclass: #HPOrderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Tests'!

!HPOrderTest methodsFor: 'testing' stamp: 'FrancoisStephany 1/29/2012 14:04'!
testGenerateXML
	| order document |
	order := HPOrder new
		issuerAccountLogin: 'francois';
		label: 'You bought the seaside book';
		urlAcquital: 'http://whatever.com/acquital';
		urlCancel: 'http://whatever.com/cancel';
		urlInstall: 'http://whatever.com/checkout';
		urlOk: 'http://whatever.com/ok';
		urlKo: 'http://whatever.com/ko';
		ageGroup: 'ALL';
		categoryId: 514;
		currency: 'EUR';
		locale: 'fr_FR';
		userAccountId: 5587.
	document := order generateXML.

	self assert: (document findElementNamed: 'issuerAccountLogin') contentString equals: 'francois'.
	self assert: (document findElementNamed: 'label') contentString equals: 'You bought the seaside book'.
	self assert: (document findElementNamed: 'urlAcquital') contentString equals: 'http://whatever.com/acquital'.
	self assert: (document findElementNamed: 'urlCancel') contentString equals: 'http://whatever.com/cancel'.
	self assert: (document findElementNamed: 'urlInstall') contentString equals: 'http://whatever.com/checkout'.
	self assert: (document findElementNamed: 'urlOk') contentString equals: 'http://whatever.com/ok'.
	self assert: (document findElementNamed: 'urlKo') contentString equals: 'http://whatever.com/ko'.
	self assert: (document findElementNamed: 'ageGroup') contentString equals: 'ALL'.
	self assert: (document findElementNamed: 'categoryId') contentString equals: '514'.
	self assert: (document findElementNamed: 'currency') contentString equals: 'EUR'.
	self assert: (document findElementNamed: 'locale') contentString equals: 'fr_FR'.
	self assert: (document findElementNamed: 'userAccountId') contentString equals: '5587'.! !

!HPOrderTest methodsFor: 'testing' stamp: 'FrancoisStephany 1/29/2012 14:49'!
testSetFieldsForEnvironment
	| order env |
	order := HPOrder new
		categoryId: 514;
		userAccountId: 5587.
	env := HPEnvironment new
		categoryId: 222;
		userAccountId: 333.
	order setFieldsForEnvironment: env.
	
	self assert: order categoryId equals: 222.
	self assert: order userAccountId equals: 333
	! !

TestCase subclass: #HPTaxTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Tests'!

!HPTaxTest methodsFor: 'testing' stamp: 'FrancoisStephany 1/29/2012 14:17'!
testGenerateXMLElementWithId
	| tax node |
	tax := HPTax new
		amount: '43';
		label: 'VAT'.	
	node := tax generateXMLElementWithId: 7.
	
	self assert: (node attributeAt: 'id') equals: '7'.
	self assert: (node findElementNamed: 'amount') contentString equals: '43'.
	self assert: (node findElementNamed: 'label') contentString equals: 'VAT'.! !

TestCase subclass: #HPXMLSerializableTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Tests'!

!HPXMLSerializableTest methodsFor: 'testing' stamp: 'FrancoisStephany 1/29/2012 16:59'!
testAddFieldsOn
	| orderItem testNode |
	testNode := XMLElement named: 'test'.
	HPOrderItem new
		reference: 'blop';
		categoryId: 545;
		addFieldsOn: testNode.
	
	self assert: (testNode findElementNamed: 'reference') contentString equals: 'blop'.
	self assert: (testNode findElementNamed: 'categoryId') contentString equals: '545'.
	
	"does not create node for nil properties"
	self assert: (testNode findElementNamed: 'amount') isNil.! !
